==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/sk.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "ukladám...",
    "saved!" : "uložené!",
    "failed!" : "neúspešné!",
    "Saved" : "Uložené",
    "There was a problem saving your changes. Click to resume editing." : "Vyskytol sa problém s ukladaním zmien. Kliknite pre pokračovanie v úpravách.",
    "An error occurred!" : "Vyskytla sa chyba!",
    "Edit" : "Upraviť",
    "Mixed" : "Zmiešaný",
    "Preview" : "Náhľad",
    "New text file" : "Nový textový súbor",
    "New text file.txt" : "Nový text file.txt",
    "You can not open a folder" : "Tento priečinok nemôžete otvoriť",
    "This file is too big to be opened. Please download the file instead." : "Tento súbor je príliš veľký na to, aby ho bolo možné otvoriť. Prosím, namiesto toho si ho stiahnite.",
    "Cannot read the file." : "Nemožno čítať súbor.",
    "Invalid file path supplied." : "Neplatná cesta k súboru.",
    "The file is locked." : "Súbor je zamknutý.",
    "An internal server error occurred." : "Vyskytla sa vnútorná chyba na serveri.",
    "You can not write to a folder" : "Do tohto priečinka nemôžete zapisovať",
    "Cannot save file as it has been modified since opening" : "Nie je možné uložiť súbor, pretože bol od otvorenia zmenený",
    "Insufficient permissions" : "Nedostatočné oprávnenia",
    "File path not supplied" : "Nebola uvedená cesta k súboru",
    "File mtime not supplied" : "Nebol uvedený mtime súboru",
    "Text editor" : "Textový editor",
    "Text file" : "Textový súbor"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/sk.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "ukladám...",
    "saved!" : "uložené!",
    "failed!" : "neúspešné!",
    "Saved" : "Uložené",
    "There was a problem saving your changes. Click to resume editing." : "Vyskytol sa problém s ukladaním zmien. Kliknite pre pokračovanie v úpravách.",
    "An error occurred!" : "Vyskytla sa chyba!",
    "Edit" : "Upraviť",
    "Mixed" : "Zmiešaný",
    "Preview" : "Náhľad",
    "New text file" : "Nový textový súbor",
    "New text file.txt" : "Nový text file.txt",
    "You can not open a folder" : "Tento priečinok nemôžete otvoriť",
    "This file is too big to be opened. Please download the file instead." : "Tento súbor je príliš veľký na to, aby ho bolo možné otvoriť. Prosím, namiesto toho si ho stiahnite.",
    "Cannot read the file." : "Nemožno čítať súbor.",
    "Invalid file path supplied." : "Neplatná cesta k súboru.",
    "The file is locked." : "Súbor je zamknutý.",
    "An internal server error occurred." : "Vyskytla sa vnútorná chyba na serveri.",
    "You can not write to a folder" : "Do tohto priečinka nemôžete zapisovať",
    "Cannot save file as it has been modified since opening" : "Nie je možné uložiť súbor, pretože bol od otvorenia zmenený",
    "Insufficient permissions" : "Nedostatočné oprávnenia",
    "File path not supplied" : "Nebola uvedená cesta k súboru",
    "File mtime not supplied" : "Nebol uvedený mtime súboru",
    "Text editor" : "Textový editor"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
